==> skrooge-1.3.3.tar.bz2: skrooge-1.3.3/plugins/applet/highlightedoperation/highlightedoperationskroogoid.h <==
/***************************************************************************
 *   Copyright (C) 2010 by SIDDHARTH SHARMA siddharth.kde@gmail.com        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/

#ifndef HIGHLIGHTEDOPERATIONSKROOGOID_H
#define HIGHLIGHTEDOPERATIONSKROOGOID_H
/** @file
* This file is Plasma Applet for Highlighted Operation Skroogoid
*
* @author Siddharth SHARMA
*/
#include <Plasma/Applet>
#include <Plasma/Label>
#include "skgservices.h"
#include <QGraphicsLinearLayout>

class QGraphicsGridLayout;
/**
 * Class HighlightedOperationSkroogoid
 */
class HighlightedOperationSkroogoid : public Plasma::Applet
{
    Q_OBJECT

public:
    /**
    * Default Constructor
    */
    HighlightedOperationSkroogoid(QObject* parent, const QVariantList& args);

    /**
     * Reimplemented from Plasma::Applet
     */
    virtual void init();

    /**
    * Default Destructor
    */
    ~HighlightedOperationSkroogoid();

private Q_SLOTS:
    /**
     * Fetch data from the specified source
     */
    void dataUpdated(const QString& sourceName, const Plasma::DataEngine::Data& engineData);

private:
    /**
     * The primary unit defined for the document
     */
    SKGServices::SKGUnitInfo primary;

    QGraphicsLinearLayout* widgetLayout;

};

/**
  * For exporting skroogoid as a registered Plasma Applet
  */
K_EXPORT_PLASMA_APPLET(highlightedoperationskroogoid, HighlightedOperationSkroogoid)

#endif

==> skrooge-1.10.92.tar.bz2: skrooge-1.10.92/plugins/applet/highlightedoperation/highlightedoperationskroogoid.h <==
/***************************************************************************
 *   Copyright (C) 2010 by SIDDHARTH SHARMA siddharth.kde@gmail.com        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/

#ifndef HIGHLIGHTEDOPERATIONSKROOGOID_H
#define HIGHLIGHTEDOPERATIONSKROOGOID_H
/** @file
* This file is Plasma Applet for Highlighted Operation Skroogoid
*
* @author Siddharth SHARMA
*/
#include <Plasma/Applet>
#include <Plasma/Label>
#include "skgservices.h"
#include <QGraphicsLinearLayout>

class QGraphicsGridLayout;
/**
 * Class HighlightedOperationSkroogoid
 */
class HighlightedOperationSkroogoid : public Plasma::Applet
{
    Q_OBJECT

public:
    /**
    * Default Constructor
    */
    explicit HighlightedOperationSkroogoid(QObject* iParent, const QVariantList& args);

    /**
     * Reimplemented from Plasma::Applet
     */
    virtual void init();

    /**
    * Default Destructor
    */
    ~HighlightedOperationSkroogoid();

private Q_SLOTS:
    /**
     * Fetch data from the specified source
     */
    void dataUpdated(const QString& sourceName, const Plasma::DataEngine::Data& engineData);

private:
    /**
     * The primary unit defined for the document
     */
    SKGServices::SKGUnitInfo primary;

    QGraphicsLinearLayout* widgetLayout;

};

/**
  * For exporting skroogoid as a registered Plasma Applet
  */
K_EXPORT_PLASMA_APPLET(highlightedoperationskroogoid, HighlightedOperationSkroogoid)

#endif
